@@ -1,8 +1,10 @@
+# frozen_string_literal: true
+
 describe WPScan::Finders::Plugins::KnownLocations do
   subject(:finder) { described_class.new(target) }
   let(:target)     { WPScan::Target.new(url) }
   let(:url)        { 'http://ex.lo/' }
-  let(:fixtures)   { File.join(FINDERS_FIXTURES, 'plugins', 'known_locations') }
+  let(:fixtures)   { FINDERS_FIXTURES.join('plugins', 'known_locations') }
 
   describe '#aggressive' do
     xit
